#!/usr/bin/env python
import sys
from coverage import coverage
from optparse import OptionParser

from django.conf import settings


if not settings.configured:
    settings.configure(
            DATABASES={
                'default': {
                    'ENGINE': 'django.db.backends.sqlite3',
                    }
                },
            INSTALLED_APPS=[
                'django.contrib.auth',
                'django.contrib.admin',
                'django.contrib.contenttypes',
                'django.contrib.sessions',
                'django.contrib.sites',
                'oscar_stripe',
                'south',
                ],
            DEBUG=False,
            SITE_ID=1,
            NOSE_ARGS=['-s', '--with-spec'],
        )

# Needs to be here to avoid missing SETTINGS env var
from django_nose import NoseTestSuiteRunner


def run_tests(*test_args):
    if 'south' in settings.INSTALLED_APPS:
        from south.management.commands import patch_for_test_db_setup
        patch_for_test_db_setup()

    if not test_args:
        test_args = ['tests']

    # Run tests
    test_runner = NoseTestSuiteRunner(verbosity=1)

    c = coverage(source=['oscar_stripe'], omit=['*migrations*', '*tests*'])
    c.start()
    num_failures = test_runner.run_tests(test_args)
    c.stop()

    if num_failures > 0:
        sys.exit(num_failures)
    print "Generating HTML coverage report"
    c.html_report()


if __name__ == '__main__':
    parser = OptionParser()
    (options, args) = parser.parse_args()
    run_tests(*args)



from oscar.app import Shop
from .checkout.app import application as checkout_app


class StripeShop(Shop):
    # Specify a local checkout app where we override the payment details view
    checkout_app = checkout_app


shop = StripeShop()



from django.urls import include, path
from django.conf import settings
from django.contrib import admin
from django.contrib.staticfiles.urls import staticfiles_urlpatterns
from django.urls import static, i18n

from apps.app import shop

admin.autodiscover()

urlpatterns = [
    path('^admin/', include(admin.site.urls)),
    path('^i18n/', include(i18n)),
    path('', include(shop.urls)),
]

if settings.DEBUG:
    import debug_toolbar
    urlpatterns += staticfiles_urlpatterns()
    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
    urlpatterns += [
            path('__debug__/', include(debug_toolbar.urls)),
            ]



from oscar.apps.checkout.app import CheckoutApplication

from oscar_stripe import views


class OverriddenCheckoutApplication(CheckoutApplication):
    # Specify new view for payment details
    payment_details_view = views.PaymentDetailsView


application = OverriddenCheckoutApplication()



#!/usr/bin/env python
from setuptools import setup, find_packages

setup(name='django-oscar-stripe-sandbox',
      version='0.1',
      url='https://github.com/tangentlabs/django-oscar-stripe',
      author="David Winterbottom",
      author_email="david.winterbottom@tangentlabs.co.uk",
      description="Sandbox app - Stripe payment module for django-oscar",
      keywords="Payment, Stripe",
      license='BSD',
      include_package_data=True,
      install_requires=[
          'django-oscar>=0.6',
          'stripe==1.12.0',
           # Haystack currently expects an older version (2017-11-18)
           # sandbox settings currently setup for older versions
           'Django>=1.11.19',
      ],
      dependency_links=['https://code.stripe.com/stripe/stripe-1.12.0#egg=stripe'],
      # See http://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
          'Development Status :: 4 - Beta',
          'Environment :: Web Environment',
          'Framework :: Django',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: BSD License',
          'Operating System :: Unix',
          'Programming Language :: Python']
      )
